﻿using Microsoft.Win32;

namespace TestProject;

/// <summary>
/// CUDA 헬퍼
/// </summary>
public class CUDAHelper
{
    //////////////////////////////////////////////////////////////////////////////////////////////////// Method
    ////////////////////////////////////////////////////////////////////////////////////////// Static
    //////////////////////////////////////////////////////////////////////////////// Public

    #region CUDA 설치 여부 구하기 - IsCUDAInstalled()

    /// <summary>
    /// CUDA 설치 여부 구하기
    /// </summary>
    /// <returns>CUDA 설치 여부</returns>
    public static bool IsCUDAInstalled()
    {
        try
        {
#pragma warning disable CA1416 // 플랫폼 호환성 유효성 검사
            using(RegistryKey registryKey = Registry.LocalMachine.OpenSubKey(@"SOFTWARE\NVIDIA Corporation\GPU Computing Toolkit\CUDA"))
            {
                if(registryKey != null)
                {
                    string[] subkeyNameArray = registryKey.GetSubKeyNames();

                    if(subkeyNameArray.Length > 0)
                    {
                        return true;
                    }
                }
            }
#pragma warning restore CA1416 // 플랫폼 호환성 유효성 검사

            return false;
        }
        catch
        {
            return false;
        }
    }

    #endregion
    #region CUDA 버전 구하기 - GetGUDAVersion()

    /// <summary>
    /// CUDA 버전 구하기
    /// </summary>
    /// <returns>CUDA 버전</returns>
    public static string GetGUDAVersion()
    {
        if(IsCUDAInstalled())
        {
#pragma warning disable CA1416 // 플랫폼 호환성 유효성 검사
            using(RegistryKey registryKey = Registry.LocalMachine.OpenSubKey(@"SOFTWARE\NVIDIA Corporation\GPU Computing Toolkit\CUDA"))
            {
                if(registryKey != null)
                {
                    string[] subkeyNameArray = registryKey.GetSubKeyNames();

                    if(subkeyNameArray.Length > 0)
                    {
                        string version = string.Join(", ", subkeyNameArray);

                        return version;
                    }
                }
            }
#pragma warning restore CA1416 // 플랫폼 호환성 유효성 검사

            return null;
        }
        else
        {
            return null;
        }
    }

    #endregion
}